@@ -7,8 +7,8 @@ use warnings;
 use Readonly qw (Readonly);
 use WiX3::Exceptions;
 
-our $VERSION = '0.006';
-$VERSION = eval { return $VERSION };
+our $VERSION = '0.007';
+$VERSION = eval $VERSION; ## no critic(ProhibitStringyEval)
 
 Readonly my %TYPES => ( 'Maybe[Int]' => 'an integer' );
 
@@ -37,8 +37,9 @@ sub _create_error_carpmess {
 
 	my $longmess = exists $args{longmess} ? !!$args{longmess} : 0;
 
+	## no critic 'ProhibitComplexRegexes'
 	if ($info =~ m{\A
-	               Attribute [ ] \((.*)\)  # $1 = attribute name
+	               Attribute [ ] [(] (.*) [)]  # $1 = attribute name
 				   [ ] does [ ] not [ ] pass [ ] the 
 				   [ ] type [ ] constraint [ ] because: 
 				   [ ] Validation [ ] failed [ ] for [ ] '(.*)' # $2 = type
